# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMEConnectionHandlingRuleContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "created_by": "DCMEUserView",
        "created_on": "datetime",
        "last_changed_on": "datetime",
        "source_connection_id": "str",
        "source_connection_title": "str",
        "target_connection_id": "str",
        "target_connection_title": "str",
    }

    attribute_map = {
        "id": "id",
        "created_by": "createdBy",
        "created_on": "createdOn",
        "last_changed_on": "lastChangedOn",
        "source_connection_id": "sourceConnectionId",
        "source_connection_title": "sourceConnectionTitle",
        "target_connection_id": "targetConnectionId",
        "target_connection_title": "targetConnectionTitle",
    }

    def __init__(
        self,
        id=None,
        created_by=None,
        created_on=None,
        last_changed_on=None,
        source_connection_id=None,
        source_connection_title=None,
        target_connection_id=None,
        target_connection_title=None,
        _configuration=None,
    ):  # noqa: E501
        """DCMEConnectionHandlingRuleContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_changed_on = None
        self._source_connection_id = None
        self._source_connection_title = None
        self._target_connection_id = None
        self._target_connection_title = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_changed_on is not None:
            self.last_changed_on = last_changed_on
        self.source_connection_id = source_connection_id
        if source_connection_title is not None:
            self.source_connection_title = source_connection_title
        if target_connection_id is not None:
            self.target_connection_id = target_connection_id
        if target_connection_title is not None:
            self.target_connection_title = target_connection_title

    @property
    def id(self):
        """Gets the id of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The id of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DCMEConnectionHandlingRuleContract.


        :param id: The id of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The created_by of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: DCMEUserView
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this DCMEConnectionHandlingRuleContract.


        :param created_by: The created_by of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :type: DCMEUserView
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The created_on of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DCMEConnectionHandlingRuleContract.


        :param created_on: The created_on of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :type: datetime
        """

        self._created_on = created_on

    @property
    def last_changed_on(self):
        """Gets the last_changed_on of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The last_changed_on of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: datetime
        """
        return self._last_changed_on

    @last_changed_on.setter
    def last_changed_on(self, last_changed_on):
        """Sets the last_changed_on of this DCMEConnectionHandlingRuleContract.


        :param last_changed_on: The last_changed_on of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :type: datetime
        """

        self._last_changed_on = last_changed_on

    @property
    def source_connection_id(self):
        """Gets the source_connection_id of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The source_connection_id of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: str
        """
        return self._source_connection_id

    @source_connection_id.setter
    def source_connection_id(self, source_connection_id):
        """Sets the source_connection_id of this DCMEConnectionHandlingRuleContract.


        :param source_connection_id: The source_connection_id of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and source_connection_id is None:
            raise ValueError("Invalid value for `source_connection_id`, must not be `None`")  # noqa: E501

        self._source_connection_id = source_connection_id

    @property
    def source_connection_title(self):
        """Gets the source_connection_title of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The source_connection_title of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: str
        """
        return self._source_connection_title

    @source_connection_title.setter
    def source_connection_title(self, source_connection_title):
        """Sets the source_connection_title of this DCMEConnectionHandlingRuleContract.


        :param source_connection_title:
            The source_connection_title of this DCMEConnectionHandlingRuleContract.
        :type: str
        """

        self._source_connection_title = source_connection_title

    @property
    def target_connection_id(self):
        """Gets the target_connection_id of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The target_connection_id of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: str
        """
        return self._target_connection_id

    @target_connection_id.setter
    def target_connection_id(self, target_connection_id):
        """Sets the target_connection_id of this DCMEConnectionHandlingRuleContract.


        :param target_connection_id:
            The target_connection_id of this DCMEConnectionHandlingRuleContract.
        :type: str
        """

        self._target_connection_id = target_connection_id

    @property
    def target_connection_title(self):
        """Gets the target_connection_title of this DCMEConnectionHandlingRuleContract.  # noqa: E501


        :return: The target_connection_title of this DCMEConnectionHandlingRuleContract.  # noqa: E501
        :rtype: str
        """
        return self._target_connection_title

    @target_connection_title.setter
    def target_connection_title(self, target_connection_title):
        """Sets the target_connection_title of this DCMEConnectionHandlingRuleContract.


        :param target_connection_title:
            The target_connection_title of this DCMEConnectionHandlingRuleContract.
        :type: str
        """

        self._target_connection_title = target_connection_title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMEConnectionHandlingRuleContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMEConnectionHandlingRuleContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMEConnectionHandlingRuleContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class ServerConnectionView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "connection_string": "str",
        "connection_type": "str",
        "dcm_connection_id": "str",
        "dcm_connection_title": "str",
        "user_ids": "list[str]",
        "user_group_ids": "list[str]",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "connection_string": "connectionString",
        "connection_type": "connectionType",
        "dcm_connection_id": "dcmConnectionId",
        "dcm_connection_title": "dcmConnectionTitle",
        "user_ids": "userIds",
        "user_group_ids": "userGroupIds",
    }

    def __init__(
        self,
        id=None,
        name=None,
        connection_string=None,
        connection_type=None,
        dcm_connection_id=None,
        dcm_connection_title=None,
        user_ids=None,
        user_group_ids=None,
        _configuration=None,
    ):  # noqa: E501
        """ServerConnectionView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._connection_string = None
        self._connection_type = None
        self._dcm_connection_id = None
        self._dcm_connection_title = None
        self._user_ids = None
        self._user_group_ids = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.connection_string = connection_string
        self.connection_type = connection_type
        if dcm_connection_id is not None:
            self.dcm_connection_id = dcm_connection_id
        if dcm_connection_title is not None:
            self.dcm_connection_title = dcm_connection_title
        if user_ids is not None:
            self.user_ids = user_ids
        if user_group_ids is not None:
            self.user_group_ids = user_group_ids

    @property
    def id(self):
        """Gets the id of this ServerConnectionView.  # noqa: E501


        :return: The id of this ServerConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerConnectionView.


        :param id: The id of this ServerConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ServerConnectionView.  # noqa: E501


        :return: The name of this ServerConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServerConnectionView.


        :param name: The name of this ServerConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def connection_string(self):
        """Gets the connection_string of this ServerConnectionView.  # noqa: E501


        :return: The connection_string of this ServerConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """Sets the connection_string of this ServerConnectionView.


        :param connection_string: The connection_string of this ServerConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and connection_string is None:
            raise ValueError("Invalid value for `connection_string`, must not be `None`")  # noqa: E501

        self._connection_string = connection_string

    @property
    def connection_type(self):
        """Gets the connection_type of this ServerConnectionView.  # noqa: E501


        :return: The connection_type of this ServerConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """Sets the connection_type of this ServerConnectionView.


        :param connection_type: The connection_type of this ServerConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and connection_type is None:
            raise ValueError("Invalid value for `connection_type`, must not be `None`")  # noqa: E501

        self._connection_type = connection_type

    @property
    def dcm_connection_id(self):
        """Gets the dcm_connection_id of this ServerConnectionView.  # noqa: E501


        :return: The dcm_connection_id of this ServerConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._dcm_connection_id

    @dcm_connection_id.setter
    def dcm_connection_id(self, dcm_connection_id):
        """Sets the dcm_connection_id of this ServerConnectionView.


        :param dcm_connection_id: The dcm_connection_id of this ServerConnectionView.  # noqa: E501
        :type: str
        """

        self._dcm_connection_id = dcm_connection_id

    @property
    def dcm_connection_title(self):
        """Gets the dcm_connection_title of this ServerConnectionView.  # noqa: E501


        :return: The dcm_connection_title of this ServerConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._dcm_connection_title

    @dcm_connection_title.setter
    def dcm_connection_title(self, dcm_connection_title):
        """Sets the dcm_connection_title of this ServerConnectionView.


        :param dcm_connection_title: The dcm_connection_title of this ServerConnectionView.  # noqa: E501
        :type: str
        """

        self._dcm_connection_title = dcm_connection_title

    @property
    def user_ids(self):
        """Gets the user_ids of this ServerConnectionView.  # noqa: E501


        :return: The user_ids of this ServerConnectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """Sets the user_ids of this ServerConnectionView.


        :param user_ids: The user_ids of this ServerConnectionView.  # noqa: E501
        :type: list[str]
        """

        self._user_ids = user_ids

    @property
    def user_group_ids(self):
        """Gets the user_group_ids of this ServerConnectionView.  # noqa: E501


        :return: The user_group_ids of this ServerConnectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_group_ids

    @user_group_ids.setter
    def user_group_ids(self, user_group_ids):
        """Sets the user_group_ids of this ServerConnectionView.


        :param user_group_ids: The user_group_ids of this ServerConnectionView.  # noqa: E501
        :type: list[str]
        """

        self._user_group_ids = user_group_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ServerConnectionView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerConnectionView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ServerConnectionView):
            return True

        return self.to_dict() != other.to_dict()



import click
from src.mcp_server import MCPAlteryxServer
import logging
#import netifaces

logger = logging.getLogger(__name__)


@click.command()
@click.option(
    "--transport",
    type=click.Choice(["stdio", "sse", "streamable-http"]),
    default="stdio",
    help="Transport type",
)
@click.option(
    "--log-level",
    default="INFO",
    help="Logging level (DEBUG, INFO, WARNING, ERROR, CRITICAL)",
)
def main(transport: str, log_level: str) -> None:
    # Configure logging
    logging.basicConfig(
        level=getattr(logging, log_level.upper()),
        format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
    )

    # Log all available IP addresses and their MAC addresses
    # def list_ip_addresses_and_mac_addresses():
    #     network_info = {}
    #     try:
    #         # Get all network interfaces
    #         interfaces = netifaces.interfaces()
    #         for interface in interfaces:
    #             try:
    #                 # Get IP addresses
    #                 ip_addresses = netifaces.ifaddresses(interface).get(netifaces.AF_INET, [])
    #                 ip_list = [addr["addr"] for addr in ip_addresses]

    #                 # Get MAC address
    #                 mac = netifaces.ifaddresses(interface).get(netifaces.AF_LINK, [])
    #                 mac_address = mac[0]["addr"] if mac else None

    #                 if ip_list or mac_address:
    #                     network_info[interface] = {"ip_addresses": ip_list, "mac_address": mac_address}
    #             except Exception as e:
    #                 logger.error(f"Error getting info for interface {interface}: {e}")
    #     except Exception as e:
    #         logger.error(f"Error listing network interfaces: {e}")
    #     return network_info

    # network_info = list_ip_addresses_and_mac_addresses()
    # for interface, info in network_info.items():
    #     logger.info(f"Interface: {interface}")
    #     logger.info(f"  IP Addresses: {info['ip_addresses']}")
    #     logger.info(f"  MAC Address: {info['mac_address']}")

    # Create and initialize the MCP server
    server = MCPAlteryxServer()
    server = server.initialize()
    server = server.register_tools()

    print("Starting Alteryx Server Client")
    match transport:
        case "stdio":
            server.app.run(transport="stdio")
        case "sse":
            server.app.run(transport="sse")
        case "streamable-http":
            server.app.run(transport="streamable-http")


if __name__ == "__main__":
    main(transport="sse", log_level="INFO")



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class SchedulesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def schedules_create_schedule(self, contract, **kwargs):  # noqa: E501
        """Create a new schedule.  # noqa: E501

        If TimeZone is empty or skipped then all the datetime fields will be according to timezone UTC-0 and   if the TimeZone is given then all the datetime fields will be according to that timezone provided.  Click https://help.alteryx.com/current/en/server/api-overview/alteryx-server-api-v3.html in order to view the list of valid timezones.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_create_schedule(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateScheduleContract contract: See Data Type Model for iteration type contract structures. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.schedules_create_schedule_with_http_info(contract, **kwargs)  # noqa: E501
        else:
            (data) = self.schedules_create_schedule_with_http_info(contract, **kwargs)  # noqa: E501
            return data

    def schedules_create_schedule_with_http_info(self, contract, **kwargs):  # noqa: E501
        """Create a new schedule.  # noqa: E501

        If TimeZone is empty or skipped then all the datetime fields will be according to timezone UTC-0 and   if the TimeZone is given then all the datetime fields will be according to that timezone provided.  Click https://help.alteryx.com/current/en/server/api-overview/alteryx-server-api-v3.html in order to view the list of valid timezones.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_create_schedule_with_http_info(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateScheduleContract contract: See Data Type Model for iteration type contract structures. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method schedules_create_schedule" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `schedules_create_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/schedules",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="str",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def schedules_delete_schedule(self, schedule_id, **kwargs):  # noqa: E501
        """Delete an existing schedule.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_delete_schedule(schedule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.schedules_delete_schedule_with_http_info(schedule_id, **kwargs)  # noqa: E501
        else:
            (data) = self.schedules_delete_schedule_with_http_info(schedule_id, **kwargs)  # noqa: E501
            return data

    def schedules_delete_schedule_with_http_info(self, schedule_id, **kwargs):  # noqa: E501
        """Delete an existing schedule.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_delete_schedule_with_http_info(schedule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["schedule_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method schedules_delete_schedule" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'schedule_id' is set
        if self.api_client.client_side_validation and ("schedule_id" not in params or params["schedule_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `schedule_id` when calling `schedules_delete_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "schedule_id" in params:
            path_params["scheduleId"] = params["schedule_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/schedules/{scheduleId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def schedules_get_schedule(self, schedule_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing schedule.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_get_schedule(schedule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :return: ScheduleView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.schedules_get_schedule_with_http_info(schedule_id, **kwargs)  # noqa: E501
        else:
            (data) = self.schedules_get_schedule_with_http_info(schedule_id, **kwargs)  # noqa: E501
            return data

    def schedules_get_schedule_with_http_info(self, schedule_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing schedule.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_get_schedule_with_http_info(schedule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :return: ScheduleView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["schedule_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method schedules_get_schedule" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'schedule_id' is set
        if self.api_client.client_side_validation and ("schedule_id" not in params or params["schedule_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `schedule_id` when calling `schedules_get_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "schedule_id" in params:
            path_params["scheduleId"] = params["schedule_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/schedules/{scheduleId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ScheduleView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def schedules_get_schedules(self, **kwargs):  # noqa: E501
        """Retrieve all accessible schedule records.  # noqa: E501

        When filtering using RunsAfter and RunsBefore, you are limited to 45 days apart from each other.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_get_schedules(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner_id: Filter results for a specific owner.
        :param str workflow_id: Filter results for a specific workflow.
        :param datetime runs_after: Filters by whether a schedule will run after a given date, inclusive. Should be provided as UTC-0.
        :param datetime runs_before: Filters by whether a schedule will run after a given date, exclusive. Should be provided as UTC-0.
        :param str view: How much information about each schedule to return.
        :return: list[ReducedScheduleView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.schedules_get_schedules_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.schedules_get_schedules_with_http_info(**kwargs)  # noqa: E501
            return data

    def schedules_get_schedules_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible schedule records.  # noqa: E501

        When filtering using RunsAfter and RunsBefore, you are limited to 45 days apart from each other.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_get_schedules_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner_id: Filter results for a specific owner.
        :param str workflow_id: Filter results for a specific workflow.
        :param datetime runs_after: Filters by whether a schedule will run after a given date, inclusive. Should be provided as UTC-0.
        :param datetime runs_before: Filters by whether a schedule will run after a given date, exclusive. Should be provided as UTC-0.
        :param str view: How much information about each schedule to return.
        :return: list[ReducedScheduleView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["owner_id", "workflow_id", "runs_after", "runs_before", "view"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method schedules_get_schedules" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "owner_id" in params:
            query_params.append(("ownerId", params["owner_id"]))  # noqa: E501
        if "workflow_id" in params:
            query_params.append(("workflowId", params["workflow_id"]))  # noqa: E501
        if "runs_after" in params:
            query_params.append(("runsAfter", params["runs_after"]))  # noqa: E501
        if "runs_before" in params:
            query_params.append(("runsBefore", params["runs_before"]))  # noqa: E501
        if "view" in params:
            query_params.append(("view", params["view"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/schedules",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ReducedScheduleView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def schedules_update_schedule(self, schedule_id, contract, **kwargs):  # noqa: E501
        """Update details of an existing schedule.  # noqa: E501

        If TimeZone is empty or skipped then all the datetime fields will be according to timezone UTC-0   and if the TimeZone is given then all the datetime fields will be according to that timezone provided.  Click https://help.alteryx.com/current/en/server/api-overview/alteryx-server-api-v3.html in order to view the list of valid timezones.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_update_schedule(schedule_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :param UpdateScheduleContract contract:  (required)
        :return: ScheduleView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.schedules_update_schedule_with_http_info(schedule_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.schedules_update_schedule_with_http_info(schedule_id, contract, **kwargs)  # noqa: E501
            return data

    def schedules_update_schedule_with_http_info(self, schedule_id, contract, **kwargs):  # noqa: E501
        """Update details of an existing schedule.  # noqa: E501

        If TimeZone is empty or skipped then all the datetime fields will be according to timezone UTC-0   and if the TimeZone is given then all the datetime fields will be according to that timezone provided.  Click https://help.alteryx.com/current/en/server/api-overview/alteryx-server-api-v3.html in order to view the list of valid timezones.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_update_schedule_with_http_info(schedule_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :param UpdateScheduleContract contract:  (required)
        :return: ScheduleView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["schedule_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method schedules_update_schedule" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'schedule_id' is set
        if self.api_client.client_side_validation and ("schedule_id" not in params or params["schedule_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `schedule_id` when calling `schedules_update_schedule`")  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `schedules_update_schedule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "schedule_id" in params:
            path_params["scheduleId"] = params["schedule_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/schedules/{scheduleId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ScheduleView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def schedules_update_schedule_patch(self, schedule_id, contract, **kwargs):  # noqa: E501
        """Update details of an existing schedule.  # noqa: E501

        Click https://help.alteryx.com/current/en/server/api-overview/alteryx-server-api-v3.html in order to view the list of valid timezones.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_update_schedule_patch(schedule_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :param PatchScheduleContract contract:  (required)
        :return: ScheduleView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.schedules_update_schedule_patch_with_http_info(schedule_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.schedules_update_schedule_patch_with_http_info(schedule_id, contract, **kwargs)  # noqa: E501
            return data

    def schedules_update_schedule_patch_with_http_info(self, schedule_id, contract, **kwargs):  # noqa: E501
        """Update details of an existing schedule.  # noqa: E501

        Click https://help.alteryx.com/current/en/server/api-overview/alteryx-server-api-v3.html in order to view the list of valid timezones.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schedules_update_schedule_patch_with_http_info(schedule_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str schedule_id: Identifier for an existing schedule. (required)
        :param PatchScheduleContract contract:  (required)
        :return: ScheduleView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["schedule_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method schedules_update_schedule_patch" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'schedule_id' is set
        if self.api_client.client_side_validation and ("schedule_id" not in params or params["schedule_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `schedule_id` when calling `schedules_update_schedule_patch`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `schedules_update_schedule_patch`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "schedule_id" in params:
            path_params["scheduleId"] = params["schedule_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/schedules/{scheduleId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ScheduleView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class CredentialsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def credentials_delete_credential(self, credential_id, **kwargs):  # noqa: E501
        """Delete an existing credential.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_delete_credential(credential_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param bool force: cleans up any shares
        :return: list[CredentialsView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_delete_credential_with_http_info(credential_id, **kwargs)  # noqa: E501
        else:
            (data) = self.credentials_delete_credential_with_http_info(credential_id, **kwargs)  # noqa: E501
            return data

    def credentials_delete_credential_with_http_info(self, credential_id, **kwargs):  # noqa: E501
        """Delete an existing credential.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_delete_credential_with_http_info(credential_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param bool force: cleans up any shares
        :return: list[CredentialsView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["credential_id", "force"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method credentials_delete_credential" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'credential_id' is set
        if self.api_client.client_side_validation and (
            "credential_id" not in params or params["credential_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `credential_id` when calling `credentials_delete_credential`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "credential_id" in params:
            path_params["credentialId"] = params["credential_id"]  # noqa: E501

        query_params = []
        if "force" in params:
            query_params.append(("force", params["force"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials/{credentialId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[CredentialsView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def credentials_get_credential(self, credential_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing credential.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_get_credential(credential_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_get_credential_with_http_info(credential_id, **kwargs)  # noqa: E501
        else:
            (data) = self.credentials_get_credential_with_http_info(credential_id, **kwargs)  # noqa: E501
            return data

    def credentials_get_credential_with_http_info(self, credential_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing credential.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_get_credential_with_http_info(credential_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["credential_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method credentials_get_credential" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'credential_id' is set
        if self.api_client.client_side_validation and (
            "credential_id" not in params or params["credential_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `credential_id` when calling `credentials_get_credential`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "credential_id" in params:
            path_params["credentialId"] = params["credential_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials/{credentialId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CredentialsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def credentials_get_credentials(self, **kwargs):  # noqa: E501
        """Retrieve all accessible credential records.  # noqa: E501

        If you are not a Curator, then results will be limited to credentials that you have access to and the following arguments will be disregarded: view, userId, and userGroupId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_get_credentials(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view: Determines the amount of information about each credential being returned.
        :param str user_id: Filter results for a specific user.
        :param str user_group_id: Filter results for a specific user group.
        :return: list[ReducedCredentialsView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_get_credentials_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.credentials_get_credentials_with_http_info(**kwargs)  # noqa: E501
            return data

    def credentials_get_credentials_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible credential records.  # noqa: E501

        If you are not a Curator, then results will be limited to credentials that you have access to and the following arguments will be disregarded: view, userId, and userGroupId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_get_credentials_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view: Determines the amount of information about each credential being returned.
        :param str user_id: Filter results for a specific user.
        :param str user_group_id: Filter results for a specific user group.
        :return: list[ReducedCredentialsView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["view", "user_id", "user_group_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method credentials_get_credentials" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "view" in params:
            query_params.append(("view", params["view"]))  # noqa: E501
        if "user_id" in params:
            query_params.append(("userId", params["user_id"]))  # noqa: E501
        if "user_group_id" in params:
            query_params.append(("userGroupId", params["user_group_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ReducedCredentialsView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def credentials_remove_user_from_credential(self, credential_id, user_id, **kwargs):  # noqa: E501
        """Remove a user's permissions to use an existing credential.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_remove_user_from_credential(credential_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_remove_user_from_credential_with_http_info(credential_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.credentials_remove_user_from_credential_with_http_info(credential_id, user_id, **kwargs)  # noqa: E501
            return data

    def credentials_remove_user_from_credential_with_http_info(self, credential_id, user_id, **kwargs):  # noqa: E501
        """Remove a user's permissions to use an existing credential.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_remove_user_from_credential_with_http_info(credential_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["credential_id", "user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method credentials_remove_user_from_credential" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'credential_id' is set
        if self.api_client.client_side_validation and (
            "credential_id" not in params or params["credential_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `credential_id` when calling `credentials_remove_user_from_credential`"
            )  # noqa: E501
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_id` when calling `credentials_remove_user_from_credential`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "credential_id" in params:
            path_params["credentialId"] = params["credential_id"]  # noqa: E501
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials/{credentialId}/users/{userId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CredentialsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def credentials_remove_user_group_from_credential(self, credential_id, user_group_id, **kwargs):  # noqa: E501
        """Remove a user group's permission to use an existing credential.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_remove_user_group_from_credential(credential_id, user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_remove_user_group_from_credential_with_http_info(
                credential_id, user_group_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.credentials_remove_user_group_from_credential_with_http_info(
                credential_id, user_group_id, **kwargs
            )  # noqa: E501
            return data

    def credentials_remove_user_group_from_credential_with_http_info(self, credential_id, user_group_id, **kwargs):  # noqa: E501
        """Remove a user group's permission to use an existing credential.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_remove_user_group_from_credential_with_http_info(credential_id, user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["credential_id", "user_group_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method credentials_remove_user_group_from_credential" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'credential_id' is set
        if self.api_client.client_side_validation and (
            "credential_id" not in params or params["credential_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `credential_id` when calling `credentials_remove_user_group_from_credential`"
            )  # noqa: E501
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `credentials_remove_user_group_from_credential`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "credential_id" in params:
            path_params["credentialId"] = params["credential_id"]  # noqa: E501
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials/{credentialId}/userGroups/{userGroupId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CredentialsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def credentials_share_credential_with_user(self, credential_id, contract, **kwargs):  # noqa: E501
        """Share an existing credential with an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_share_credential_with_user(credential_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param AddCredentialsUserContract contract:  (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_share_credential_with_user_with_http_info(credential_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.credentials_share_credential_with_user_with_http_info(credential_id, contract, **kwargs)  # noqa: E501
            return data

    def credentials_share_credential_with_user_with_http_info(self, credential_id, contract, **kwargs):  # noqa: E501
        """Share an existing credential with an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_share_credential_with_user_with_http_info(credential_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param AddCredentialsUserContract contract:  (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["credential_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method credentials_share_credential_with_user" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'credential_id' is set
        if self.api_client.client_side_validation and (
            "credential_id" not in params or params["credential_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `credential_id` when calling `credentials_share_credential_with_user`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `credentials_share_credential_with_user`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "credential_id" in params:
            path_params["credentialId"] = params["credential_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials/{credentialId}/users",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CredentialsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def credentials_share_credential_with_user_group(self, credential_id, contract, **kwargs):  # noqa: E501
        """Share an existing credential with an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_share_credential_with_user_group(credential_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param AddCredentialsUserGroupContract contract:  (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.credentials_share_credential_with_user_group_with_http_info(credential_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.credentials_share_credential_with_user_group_with_http_info(credential_id, contract, **kwargs)  # noqa: E501
            return data

    def credentials_share_credential_with_user_group_with_http_info(self, credential_id, contract, **kwargs):  # noqa: E501
        """Share an existing credential with an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.credentials_share_credential_with_user_group_with_http_info(credential_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credential_id: Identifier for an existing credential. (required)
        :param AddCredentialsUserGroupContract contract:  (required)
        :return: CredentialsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["credential_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method credentials_share_credential_with_user_group" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'credential_id' is set
        if self.api_client.client_side_validation and (
            "credential_id" not in params or params["credential_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `credential_id` when calling `credentials_share_credential_with_user_group`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `credentials_share_credential_with_user_group`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "credential_id" in params:
            path_params["credentialId"] = params["credential_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/credentials/{credentialId}/userGroups",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CredentialsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMEUpsertConnectionContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "schema_name": "str",
        "allow_in_sdks": "bool",
        "parameters": "dict(str, object)",
        "data_source": "DCMEObjectWrapperContractDCMEDataSourceContract",
        "credentials": "dict(str, DCMEObjectWrapperContractDCMECredentialContract)",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "schema_name": "schemaName",
        "allow_in_sdks": "allowInSdks",
        "parameters": "parameters",
        "data_source": "dataSource",
        "credentials": "credentials",
    }

    def __init__(
        self,
        id=None,
        name=None,
        schema_name=None,
        allow_in_sdks=None,
        parameters=None,
        data_source=None,
        credentials=None,
        _configuration=None,
    ):  # noqa: E501
        """DCMEUpsertConnectionContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._schema_name = None
        self._allow_in_sdks = None
        self._parameters = None
        self._data_source = None
        self._credentials = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.schema_name = schema_name
        if allow_in_sdks is not None:
            self.allow_in_sdks = allow_in_sdks
        self.parameters = parameters
        self.data_source = data_source
        self.credentials = credentials

    @property
    def id(self):
        """Gets the id of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The id of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DCMEUpsertConnectionContract.


        :param id: The id of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The name of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DCMEUpsertConnectionContract.


        :param name: The name of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def schema_name(self):
        """Gets the schema_name of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The schema_name of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """Sets the schema_name of this DCMEUpsertConnectionContract.


        :param schema_name: The schema_name of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and schema_name is None:
            raise ValueError("Invalid value for `schema_name`, must not be `None`")  # noqa: E501

        self._schema_name = schema_name

    @property
    def allow_in_sdks(self):
        """Gets the allow_in_sdks of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The allow_in_sdks of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: bool
        """
        return self._allow_in_sdks

    @allow_in_sdks.setter
    def allow_in_sdks(self, allow_in_sdks):
        """Sets the allow_in_sdks of this DCMEUpsertConnectionContract.


        :param allow_in_sdks: The allow_in_sdks of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: bool
        """

        self._allow_in_sdks = allow_in_sdks

    @property
    def parameters(self):
        """Gets the parameters of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The parameters of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this DCMEUpsertConnectionContract.


        :param parameters: The parameters of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: dict(str, object)
        """
        if self._configuration.client_side_validation and parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    @property
    def data_source(self):
        """Gets the data_source of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The data_source of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: DCMEObjectWrapperContractDCMEDataSourceContract
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this DCMEUpsertConnectionContract.


        :param data_source: The data_source of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: DCMEObjectWrapperContractDCMEDataSourceContract
        """
        if self._configuration.client_side_validation and data_source is None:
            raise ValueError("Invalid value for `data_source`, must not be `None`")  # noqa: E501

        self._data_source = data_source

    @property
    def credentials(self):
        """Gets the credentials of this DCMEUpsertConnectionContract.  # noqa: E501


        :return: The credentials of this DCMEUpsertConnectionContract.  # noqa: E501
        :rtype: dict(str, DCMEObjectWrapperContractDCMECredentialContract)
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this DCMEUpsertConnectionContract.


        :param credentials: The credentials of this DCMEUpsertConnectionContract.  # noqa: E501
        :type: dict(str, DCMEObjectWrapperContractDCMECredentialContract)
        """
        if self._configuration.client_side_validation and credentials is None:
            raise ValueError("Invalid value for `credentials`, must not be `None`")  # noqa: E501

        self._credentials = credentials

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMEUpsertConnectionContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMEUpsertConnectionContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMEUpsertConnectionContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class CollectionsPermissionsViewContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "is_admin": "bool",
        "can_add_assets": "bool",
        "can_remove_assets": "bool",
        "can_update_assets": "bool",
        "can_add_users": "bool",
        "can_remove_users": "bool",
    }

    attribute_map = {
        "is_admin": "isAdmin",
        "can_add_assets": "canAddAssets",
        "can_remove_assets": "canRemoveAssets",
        "can_update_assets": "canUpdateAssets",
        "can_add_users": "canAddUsers",
        "can_remove_users": "canRemoveUsers",
    }

    def __init__(
        self,
        is_admin=None,
        can_add_assets=None,
        can_remove_assets=None,
        can_update_assets=None,
        can_add_users=None,
        can_remove_users=None,
        _configuration=None,
    ):  # noqa: E501
        """CollectionsPermissionsViewContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._is_admin = None
        self._can_add_assets = None
        self._can_remove_assets = None
        self._can_update_assets = None
        self._can_add_users = None
        self._can_remove_users = None
        self.discriminator = None

        if is_admin is not None:
            self.is_admin = is_admin
        if can_add_assets is not None:
            self.can_add_assets = can_add_assets
        if can_remove_assets is not None:
            self.can_remove_assets = can_remove_assets
        if can_update_assets is not None:
            self.can_update_assets = can_update_assets
        if can_add_users is not None:
            self.can_add_users = can_add_users
        if can_remove_users is not None:
            self.can_remove_users = can_remove_users

    @property
    def is_admin(self):
        """Gets the is_admin of this CollectionsPermissionsViewContract.  # noqa: E501


        :return: The is_admin of this CollectionsPermissionsViewContract.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this CollectionsPermissionsViewContract.


        :param is_admin: The is_admin of this CollectionsPermissionsViewContract.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def can_add_assets(self):
        """Gets the can_add_assets of this CollectionsPermissionsViewContract.  # noqa: E501


        :return: The can_add_assets of this CollectionsPermissionsViewContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_assets

    @can_add_assets.setter
    def can_add_assets(self, can_add_assets):
        """Sets the can_add_assets of this CollectionsPermissionsViewContract.


        :param can_add_assets: The can_add_assets of this CollectionsPermissionsViewContract.  # noqa: E501
        :type: bool
        """

        self._can_add_assets = can_add_assets

    @property
    def can_remove_assets(self):
        """Gets the can_remove_assets of this CollectionsPermissionsViewContract.  # noqa: E501


        :return: The can_remove_assets of this CollectionsPermissionsViewContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_assets

    @can_remove_assets.setter
    def can_remove_assets(self, can_remove_assets):
        """Sets the can_remove_assets of this CollectionsPermissionsViewContract.


        :param can_remove_assets: The can_remove_assets of this CollectionsPermissionsViewContract.  # noqa: E501
        :type: bool
        """

        self._can_remove_assets = can_remove_assets

    @property
    def can_update_assets(self):
        """Gets the can_update_assets of this CollectionsPermissionsViewContract.  # noqa: E501


        :return: The can_update_assets of this CollectionsPermissionsViewContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_update_assets

    @can_update_assets.setter
    def can_update_assets(self, can_update_assets):
        """Sets the can_update_assets of this CollectionsPermissionsViewContract.


        :param can_update_assets: The can_update_assets of this CollectionsPermissionsViewContract.  # noqa: E501
        :type: bool
        """

        self._can_update_assets = can_update_assets

    @property
    def can_add_users(self):
        """Gets the can_add_users of this CollectionsPermissionsViewContract.  # noqa: E501


        :return: The can_add_users of this CollectionsPermissionsViewContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_add_users

    @can_add_users.setter
    def can_add_users(self, can_add_users):
        """Sets the can_add_users of this CollectionsPermissionsViewContract.


        :param can_add_users: The can_add_users of this CollectionsPermissionsViewContract.  # noqa: E501
        :type: bool
        """

        self._can_add_users = can_add_users

    @property
    def can_remove_users(self):
        """Gets the can_remove_users of this CollectionsPermissionsViewContract.  # noqa: E501


        :return: The can_remove_users of this CollectionsPermissionsViewContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_users

    @can_remove_users.setter
    def can_remove_users(self, can_remove_users):
        """Sets the can_remove_users of this CollectionsPermissionsViewContract.


        :param can_remove_users: The can_remove_users of this CollectionsPermissionsViewContract.  # noqa: E501
        :type: bool
        """

        self._can_remove_users = can_remove_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CollectionsPermissionsViewContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionsPermissionsViewContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionsPermissionsViewContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class CreateUserContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "first_name": "str",
        "last_name": "str",
        "email": "str",
        "role": "str",
        "default_worker_tag": "str",
        "can_schedule_jobs": "bool",
        "can_prioritize_jobs": "bool",
        "can_assign_jobs": "bool",
        "can_create_collections": "bool",
        "is_api_enabled": "bool",
        "default_credential_id": "str",
        "is_active": "bool",
        "time_zone": "str",
        "can_create_and_update_dcm": "bool",
        "can_share_for_execution_dcm": "bool",
        "can_share_for_collaboration_dcm": "bool",
        "can_manage_generic_vaults_dcm": "bool",
    }

    attribute_map = {
        "first_name": "firstName",
        "last_name": "lastName",
        "email": "email",
        "role": "role",
        "default_worker_tag": "defaultWorkerTag",
        "can_schedule_jobs": "canScheduleJobs",
        "can_prioritize_jobs": "canPrioritizeJobs",
        "can_assign_jobs": "canAssignJobs",
        "can_create_collections": "canCreateCollections",
        "is_api_enabled": "isApiEnabled",
        "default_credential_id": "defaultCredentialId",
        "is_active": "isActive",
        "time_zone": "timeZone",
        "can_create_and_update_dcm": "canCreateAndUpdateDcm",
        "can_share_for_execution_dcm": "canShareForExecutionDcm",
        "can_share_for_collaboration_dcm": "canShareForCollaborationDcm",
        "can_manage_generic_vaults_dcm": "canManageGenericVaultsDcm",
    }

    def __init__(
        self,
        first_name=None,
        last_name=None,
        email=None,
        role=None,
        default_worker_tag=None,
        can_schedule_jobs=None,
        can_prioritize_jobs=None,
        can_assign_jobs=None,
        can_create_collections=None,
        is_api_enabled=None,
        default_credential_id=None,
        is_active=None,
        time_zone=None,
        can_create_and_update_dcm=None,
        can_share_for_execution_dcm=None,
        can_share_for_collaboration_dcm=None,
        can_manage_generic_vaults_dcm=None,
        _configuration=None,
    ):  # noqa: E501
        """CreateUserContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._first_name = None
        self._last_name = None
        self._email = None
        self._role = None
        self._default_worker_tag = None
        self._can_schedule_jobs = None
        self._can_prioritize_jobs = None
        self._can_assign_jobs = None
        self._can_create_collections = None
        self._is_api_enabled = None
        self._default_credential_id = None
        self._is_active = None
        self._time_zone = None
        self._can_create_and_update_dcm = None
        self._can_share_for_execution_dcm = None
        self._can_share_for_collaboration_dcm = None
        self._can_manage_generic_vaults_dcm = None
        self.discriminator = None

        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        if role is not None:
            self.role = role
        if default_worker_tag is not None:
            self.default_worker_tag = default_worker_tag
        if can_schedule_jobs is not None:
            self.can_schedule_jobs = can_schedule_jobs
        if can_prioritize_jobs is not None:
            self.can_prioritize_jobs = can_prioritize_jobs
        if can_assign_jobs is not None:
            self.can_assign_jobs = can_assign_jobs
        if can_create_collections is not None:
            self.can_create_collections = can_create_collections
        if is_api_enabled is not None:
            self.is_api_enabled = is_api_enabled
        if default_credential_id is not None:
            self.default_credential_id = default_credential_id
        if is_active is not None:
            self.is_active = is_active
        if time_zone is not None:
            self.time_zone = time_zone
        if can_create_and_update_dcm is not None:
            self.can_create_and_update_dcm = can_create_and_update_dcm
        if can_share_for_execution_dcm is not None:
            self.can_share_for_execution_dcm = can_share_for_execution_dcm
        if can_share_for_collaboration_dcm is not None:
            self.can_share_for_collaboration_dcm = can_share_for_collaboration_dcm
        if can_manage_generic_vaults_dcm is not None:
            self.can_manage_generic_vaults_dcm = can_manage_generic_vaults_dcm

    @property
    def first_name(self):
        """Gets the first_name of this CreateUserContract.  # noqa: E501


        :return: The first_name of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CreateUserContract.


        :param first_name:
            The first_name of this CreateUserContract.
        :type: str
        """
        if self._configuration.client_side_validation and first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501
        if self._configuration.client_side_validation and first_name is not None and len(first_name) > 255:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `255`")  # noqa: E501
        if self._configuration.client_side_validation and first_name is not None and len(first_name) < 1:
            raise ValueError("Invalid value for `first_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this CreateUserContract.  # noqa: E501


        :return: The last_name of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CreateUserContract.


        :param last_name:
            The last_name of this CreateUserContract.
        :type: str
        """
        if self._configuration.client_side_validation and last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501
        if self._configuration.client_side_validation and last_name is not None and len(last_name) > 255:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `255`")  # noqa: E501
        if self._configuration.client_side_validation and last_name is not None and len(last_name) < 1:
            raise ValueError("Invalid value for `last_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this CreateUserContract.  # noqa: E501


        :return: The email of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CreateUserContract.


        :param email:
            The email of this CreateUserContract.
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def role(self):
        """Gets the role of this CreateUserContract.  # noqa: E501

        If no role is provided, the user will be set as Evaluated.
        Accepted values are "NoAccess", "Viewer", "Member", "Artisan", "Curator", "Evaluated"  # noqa: E501

        :return: The role of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this CreateUserContract.

        If no role is provided, the user will be set as Evaluated.
        Accepted values are "NoAccess", "Viewer", "Member", "Artisan", "Curator", "Evaluated"  # noqa: E501

        :param role:
            The role of this CreateUserContract.
        :type: str
        """

        self._role = role

    @property
    def default_worker_tag(self):
        """Gets the default_worker_tag of this CreateUserContract.  # noqa: E501


        :return: The default_worker_tag of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._default_worker_tag

    @default_worker_tag.setter
    def default_worker_tag(self, default_worker_tag):
        """Sets the default_worker_tag of this CreateUserContract.


        :param default_worker_tag:
            The default_worker_tag of this CreateUserContract.
        :type: str
        """

        self._default_worker_tag = default_worker_tag

    @property
    def can_schedule_jobs(self):
        """Gets the can_schedule_jobs of this CreateUserContract.  # noqa: E501


        :return: The can_schedule_jobs of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_schedule_jobs

    @can_schedule_jobs.setter
    def can_schedule_jobs(self, can_schedule_jobs):
        """Sets the can_schedule_jobs of this CreateUserContract.


        :param can_schedule_jobs:
            The can_schedule_jobs of this CreateUserContract.
        :type: bool
        """

        self._can_schedule_jobs = can_schedule_jobs

    @property
    def can_prioritize_jobs(self):
        """Gets the can_prioritize_jobs of this CreateUserContract.  # noqa: E501


        :return: The can_prioritize_jobs of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_prioritize_jobs

    @can_prioritize_jobs.setter
    def can_prioritize_jobs(self, can_prioritize_jobs):
        """Sets the can_prioritize_jobs of this CreateUserContract.


        :param can_prioritize_jobs:
            The can_prioritize_jobs of this CreateUserContract.
        :type: bool
        """

        self._can_prioritize_jobs = can_prioritize_jobs

    @property
    def can_assign_jobs(self):
        """Gets the can_assign_jobs of this CreateUserContract.  # noqa: E501


        :return: The can_assign_jobs of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_assign_jobs

    @can_assign_jobs.setter
    def can_assign_jobs(self, can_assign_jobs):
        """Sets the can_assign_jobs of this CreateUserContract.


        :param can_assign_jobs:
            The can_assign_jobs of this CreateUserContract.
        :type: bool
        """

        self._can_assign_jobs = can_assign_jobs

    @property
    def can_create_collections(self):
        """Gets the can_create_collections of this CreateUserContract.  # noqa: E501


        :return: The can_create_collections of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_create_collections

    @can_create_collections.setter
    def can_create_collections(self, can_create_collections):
        """Sets the can_create_collections of this CreateUserContract.


        :param can_create_collections: The can_create_collections of this CreateUserContract.  # noqa: E501
        :type: bool
        """

        self._can_create_collections = can_create_collections

    @property
    def is_api_enabled(self):
        """Gets the is_api_enabled of this CreateUserContract.  # noqa: E501


        :return: The is_api_enabled of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._is_api_enabled

    @is_api_enabled.setter
    def is_api_enabled(self, is_api_enabled):
        """Sets the is_api_enabled of this CreateUserContract.


        :param is_api_enabled:
            The is_api_enabled of this CreateUserContract.
        :type: bool
        """

        self._is_api_enabled = is_api_enabled

    @property
    def default_credential_id(self):
        """Gets the default_credential_id of this CreateUserContract.  # noqa: E501


        :return: The default_credential_id of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._default_credential_id

    @default_credential_id.setter
    def default_credential_id(self, default_credential_id):
        """Sets the default_credential_id of this CreateUserContract.


        :param default_credential_id:
            The default_credential_id of this CreateUserContract.
        :type: str
        """

        self._default_credential_id = default_credential_id

    @property
    def is_active(self):
        """Gets the is_active of this CreateUserContract.  # noqa: E501


        :return: The is_active of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this CreateUserContract.


        :param is_active:
            The is_active of this CreateUserContract.
        :type: bool
        """

        self._is_active = is_active

    @property
    def time_zone(self):
        """Gets the time_zone of this CreateUserContract.  # noqa: E501


        :return: The time_zone of this CreateUserContract.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this CreateUserContract.


        :param time_zone:
            The time_zone of this CreateUserContract.
        :type: str
        """

        self._time_zone = time_zone

    @property
    def can_create_and_update_dcm(self):
        """Gets the can_create_and_update_dcm of this CreateUserContract.  # noqa: E501


        :return: The can_create_and_update_dcm of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_create_and_update_dcm

    @can_create_and_update_dcm.setter
    def can_create_and_update_dcm(self, can_create_and_update_dcm):
        """Sets the can_create_and_update_dcm of this CreateUserContract.


        :param can_create_and_update_dcm:
            The can_create_and_update_dcm of this CreateUserContract.
        :type: bool
        """

        self._can_create_and_update_dcm = can_create_and_update_dcm

    @property
    def can_share_for_execution_dcm(self):
        """Gets the can_share_for_execution_dcm of this CreateUserContract.  # noqa: E501


        :return: The can_share_for_execution_dcm of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_share_for_execution_dcm

    @can_share_for_execution_dcm.setter
    def can_share_for_execution_dcm(self, can_share_for_execution_dcm):
        """Sets the can_share_for_execution_dcm of this CreateUserContract.


        :param can_share_for_execution_dcm:
            The can_share_for_execution_dcm of this CreateUserContract.
        :type: bool
        """

        self._can_share_for_execution_dcm = can_share_for_execution_dcm

    @property
    def can_share_for_collaboration_dcm(self):
        """Gets the can_share_for_collaboration_dcm of this CreateUserContract.  # noqa: E501


        :return: The can_share_for_collaboration_dcm of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_share_for_collaboration_dcm

    @can_share_for_collaboration_dcm.setter
    def can_share_for_collaboration_dcm(self, can_share_for_collaboration_dcm):
        """Sets the can_share_for_collaboration_dcm of this CreateUserContract.


        :param can_share_for_collaboration_dcm:
            The can_share_for_collaboration_dcm of this CreateUserContract.
        :type: bool
        """

        self._can_share_for_collaboration_dcm = can_share_for_collaboration_dcm

    @property
    def can_manage_generic_vaults_dcm(self):
        """Gets the can_manage_generic_vaults_dcm of this CreateUserContract.  # noqa: E501


        :return: The can_manage_generic_vaults_dcm of this CreateUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_generic_vaults_dcm

    @can_manage_generic_vaults_dcm.setter
    def can_manage_generic_vaults_dcm(self, can_manage_generic_vaults_dcm):
        """Sets the can_manage_generic_vaults_dcm of this CreateUserContract.


        :param can_manage_generic_vaults_dcm:
            The can_manage_generic_vaults_dcm of this CreateUserContract.
        :type: bool
        """

        self._can_manage_generic_vaults_dcm = can_manage_generic_vaults_dcm

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateUserContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateUserContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateUserContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class JobsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def jobs_get_job_messages(self, job_id, **kwargs):  # noqa: E501
        """Retrieve all messages of a specific job.  # noqa: E501

        Only Curators can use this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_get_job_messages(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Identifier for a job that has been run. (required)
        :return: JobMessageView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.jobs_get_job_messages_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.jobs_get_job_messages_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def jobs_get_job_messages_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """Retrieve all messages of a specific job.  # noqa: E501

        Only Curators can use this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_get_job_messages_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Identifier for a job that has been run. (required)
        :return: JobMessageView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["job_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method jobs_get_job_messages" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ("job_id" not in params or params["job_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `job_id` when calling `jobs_get_job_messages`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "job_id" in params:
            path_params["jobId"] = params["job_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/jobs/{jobId}/messages",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="JobMessageView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def jobs_get_job_v3(self, job_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing job and its current state.  # noqa: E501

        Only app workflows can be used.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_get_job_v3(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Identifier for a job that's running or in queue. (required)
        :param bool include_messages:
        :return: JobView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.jobs_get_job_v3_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.jobs_get_job_v3_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def jobs_get_job_v3_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing job and its current state.  # noqa: E501

        Only app workflows can be used.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_get_job_v3_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Identifier for a job that's running or in queue. (required)
        :param bool include_messages:
        :return: JobView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["job_id", "include_messages"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method jobs_get_job_v3" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ("job_id" not in params or params["job_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `job_id` when calling `jobs_get_job_v3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "job_id" in params:
            path_params["jobId"] = params["job_id"]  # noqa: E501

        query_params = []
        if "include_messages" in params:
            query_params.append(("includeMessages", params["include_messages"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/jobs/{jobId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="JobView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMEDataSourceView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "schema_name": "str",
        "drv_name": "str",
        "host": "str",
        "parameters": "dict(str, object)",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "schema_name": "schemaName",
        "drv_name": "drvName",
        "host": "host",
        "parameters": "parameters",
    }

    def __init__(
        self, id=None, name=None, schema_name=None, drv_name=None, host=None, parameters=None, _configuration=None
    ):  # noqa: E501
        """DCMEDataSourceView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._schema_name = None
        self._drv_name = None
        self._host = None
        self._parameters = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.schema_name = schema_name
        if drv_name is not None:
            self.drv_name = drv_name
        if host is not None:
            self.host = host
        self.parameters = parameters

    @property
    def id(self):
        """Gets the id of this DCMEDataSourceView.  # noqa: E501


        :return: The id of this DCMEDataSourceView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DCMEDataSourceView.


        :param id: The id of this DCMEDataSourceView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this DCMEDataSourceView.  # noqa: E501


        :return: The name of this DCMEDataSourceView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DCMEDataSourceView.


        :param name: The name of this DCMEDataSourceView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def schema_name(self):
        """Gets the schema_name of this DCMEDataSourceView.  # noqa: E501


        :return: The schema_name of this DCMEDataSourceView.  # noqa: E501
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """Sets the schema_name of this DCMEDataSourceView.


        :param schema_name: The schema_name of this DCMEDataSourceView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and schema_name is None:
            raise ValueError("Invalid value for `schema_name`, must not be `None`")  # noqa: E501

        self._schema_name = schema_name

    @property
    def drv_name(self):
        """Gets the drv_name of this DCMEDataSourceView.  # noqa: E501


        :return: The drv_name of this DCMEDataSourceView.  # noqa: E501
        :rtype: str
        """
        return self._drv_name

    @drv_name.setter
    def drv_name(self, drv_name):
        """Sets the drv_name of this DCMEDataSourceView.


        :param drv_name: The drv_name of this DCMEDataSourceView.  # noqa: E501
        :type: str
        """

        self._drv_name = drv_name

    @property
    def host(self):
        """Gets the host of this DCMEDataSourceView.  # noqa: E501


        :return: The host of this DCMEDataSourceView.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this DCMEDataSourceView.


        :param host: The host of this DCMEDataSourceView.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def parameters(self):
        """Gets the parameters of this DCMEDataSourceView.  # noqa: E501


        :return: The parameters of this DCMEDataSourceView.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this DCMEDataSourceView.


        :param parameters: The parameters of this DCMEDataSourceView.  # noqa: E501
        :type: dict(str, object)
        """
        if self._configuration.client_side_validation and parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMEDataSourceView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMEDataSourceView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMEDataSourceView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class WorkflowDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "is_amp": "bool",
        "file_name": "str",
        "author": "str",
        "copyright": "str",
        "description": "str",
        "name": "str",
        "no_output_files_message": "str",
        "output_message": "str",
        "url": "str",
        "url_text": "str",
    }

    attribute_map = {
        "is_amp": "isAmp",
        "file_name": "fileName",
        "author": "author",
        "copyright": "copyright",
        "description": "description",
        "name": "name",
        "no_output_files_message": "noOutputFilesMessage",
        "output_message": "outputMessage",
        "url": "url",
        "url_text": "urlText",
    }

    def __init__(
        self,
        is_amp=None,
        file_name=None,
        author=None,
        copyright=None,
        description=None,
        name=None,
        no_output_files_message=None,
        output_message=None,
        url=None,
        url_text=None,
        _configuration=None,
    ):  # noqa: E501
        """WorkflowDetails - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._is_amp = None
        self._file_name = None
        self._author = None
        self._copyright = None
        self._description = None
        self._name = None
        self._no_output_files_message = None
        self._output_message = None
        self._url = None
        self._url_text = None
        self.discriminator = None

        self.is_amp = is_amp
        self.file_name = file_name
        self.author = author
        self.copyright = copyright
        self.description = description
        self.name = name
        self.no_output_files_message = no_output_files_message
        self.output_message = output_message
        self.url = url
        self.url_text = url_text

    @property
    def is_amp(self):
        """Gets the is_amp of this WorkflowDetails.  # noqa: E501


        :return: The is_amp of this WorkflowDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_amp

    @is_amp.setter
    def is_amp(self, is_amp):
        """Sets the is_amp of this WorkflowDetails.


        :param is_amp: The is_amp of this WorkflowDetails.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_amp is None:
            raise ValueError("Invalid value for `is_amp`, must not be `None`")  # noqa: E501

        self._is_amp = is_amp

    @property
    def file_name(self):
        """Gets the file_name of this WorkflowDetails.  # noqa: E501


        :return: The file_name of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this WorkflowDetails.


        :param file_name: The file_name of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    @property
    def author(self):
        """Gets the author of this WorkflowDetails.  # noqa: E501


        :return: The author of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this WorkflowDetails.


        :param author: The author of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and author is None:
            raise ValueError("Invalid value for `author`, must not be `None`")  # noqa: E501

        self._author = author

    @property
    def copyright(self):
        """Gets the copyright of this WorkflowDetails.  # noqa: E501


        :return: The copyright of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._copyright

    @copyright.setter
    def copyright(self, copyright):
        """Sets the copyright of this WorkflowDetails.


        :param copyright: The copyright of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and copyright is None:
            raise ValueError("Invalid value for `copyright`, must not be `None`")  # noqa: E501

        self._copyright = copyright

    @property
    def description(self):
        """Gets the description of this WorkflowDetails.  # noqa: E501


        :return: The description of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowDetails.


        :param description: The description of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def name(self):
        """Gets the name of this WorkflowDetails.  # noqa: E501


        :return: The name of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowDetails.


        :param name: The name of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def no_output_files_message(self):
        """Gets the no_output_files_message of this WorkflowDetails.  # noqa: E501


        :return: The no_output_files_message of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._no_output_files_message

    @no_output_files_message.setter
    def no_output_files_message(self, no_output_files_message):
        """Sets the no_output_files_message of this WorkflowDetails.


        :param no_output_files_message: The no_output_files_message of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and no_output_files_message is None:
            raise ValueError("Invalid value for `no_output_files_message`, must not be `None`")  # noqa: E501

        self._no_output_files_message = no_output_files_message

    @property
    def output_message(self):
        """Gets the output_message of this WorkflowDetails.  # noqa: E501


        :return: The output_message of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._output_message

    @output_message.setter
    def output_message(self, output_message):
        """Sets the output_message of this WorkflowDetails.


        :param output_message: The output_message of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and output_message is None:
            raise ValueError("Invalid value for `output_message`, must not be `None`")  # noqa: E501

        self._output_message = output_message

    @property
    def url(self):
        """Gets the url of this WorkflowDetails.  # noqa: E501


        :return: The url of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WorkflowDetails.


        :param url: The url of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def url_text(self):
        """Gets the url_text of this WorkflowDetails.  # noqa: E501


        :return: The url_text of this WorkflowDetails.  # noqa: E501
        :rtype: str
        """
        return self._url_text

    @url_text.setter
    def url_text(self, url_text):
        """Sets the url_text of this WorkflowDetails.


        :param url_text: The url_text of this WorkflowDetails.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and url_text is None:
            raise ValueError("Invalid value for `url_text`, must not be `None`")  # noqa: E501

        self._url_text = url_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(WorkflowDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class IterationContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "iteration_type": "str",
        "start_time": "datetime",
        "end_time": "datetime",
        "hourly_contract": "IterationHourlyContract",
        "daily_contract": "IterationDailyContract",
        "weekly_contract": "IterationWeeklyContract",
        "monthly_contract": "IterationMonthlyContract",
        "custom_contract": "IterationCustomContract",
    }

    attribute_map = {
        "iteration_type": "iterationType",
        "start_time": "startTime",
        "end_time": "endTime",
        "hourly_contract": "hourlyContract",
        "daily_contract": "dailyContract",
        "weekly_contract": "weeklyContract",
        "monthly_contract": "monthlyContract",
        "custom_contract": "customContract",
    }

    def __init__(
        self,
        iteration_type=None,
        start_time=None,
        end_time=None,
        hourly_contract=None,
        daily_contract=None,
        weekly_contract=None,
        monthly_contract=None,
        custom_contract=None,
        _configuration=None,
    ):  # noqa: E501
        """IterationContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._iteration_type = None
        self._start_time = None
        self._end_time = None
        self._hourly_contract = None
        self._daily_contract = None
        self._weekly_contract = None
        self._monthly_contract = None
        self._custom_contract = None
        self.discriminator = None

        self.iteration_type = iteration_type
        self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if hourly_contract is not None:
            self.hourly_contract = hourly_contract
        if daily_contract is not None:
            self.daily_contract = daily_contract
        if weekly_contract is not None:
            self.weekly_contract = weekly_contract
        if monthly_contract is not None:
            self.monthly_contract = monthly_contract
        if custom_contract is not None:
            self.custom_contract = custom_contract

    @property
    def iteration_type(self):
        """Gets the iteration_type of this IterationContract.  # noqa: E501


        :return: The iteration_type of this IterationContract.  # noqa: E501
        :rtype: str
        """
        return self._iteration_type

    @iteration_type.setter
    def iteration_type(self, iteration_type):
        """Sets the iteration_type of this IterationContract.


        :param iteration_type: The iteration_type of this IterationContract.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and iteration_type is None:
            raise ValueError("Invalid value for `iteration_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Once", "Hourly", "Weekly", "Monthly", "Custom", "Daily"]  # noqa: E501
        if self._configuration.client_side_validation and iteration_type not in allowed_values:
            raise ValueError(
                "Invalid value for `iteration_type` ({0}), must be one of {1}".format(iteration_type, allowed_values)  # noqa: E501
            )

        self._iteration_type = iteration_type

    @property
    def start_time(self):
        """Gets the start_time of this IterationContract.  # noqa: E501

        Start Date Time as UTC-0  # noqa: E501

        :return: The start_time of this IterationContract.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this IterationContract.

        Start Date Time as UTC-0  # noqa: E501

        :param start_time: The start_time of this IterationContract.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this IterationContract.  # noqa: E501

        End Date Time as UTC-0  Optional, if excluded the iteration will be indefinite.   
            Ignored for "Single" IterationType  # noqa: E501

        :return: The end_time of this IterationContract.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this IterationContract.

        End Date Time as UTC-0  Optional, if excluded the iteration will be indefinite.   
        Ignored for "Single" IterationType  # noqa: E501

        :param end_time: The end_time of this IterationContract.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def hourly_contract(self):
        """Gets the hourly_contract of this IterationContract.  # noqa: E501

        Required when the IterationType is Hourly  # noqa: E501

        :return: The hourly_contract of this IterationContract.  # noqa: E501
        :rtype: IterationHourlyContract
        """
        return self._hourly_contract

    @hourly_contract.setter
    def hourly_contract(self, hourly_contract):
        """Sets the hourly_contract of this IterationContract.

        Required when the IterationType is Hourly  # noqa: E501

        :param hourly_contract: The hourly_contract of this IterationContract.  # noqa: E501
        :type: IterationHourlyContract
        """

        self._hourly_contract = hourly_contract

    @property
    def daily_contract(self):
        """Gets the daily_contract of this IterationContract.  # noqa: E501

        Required when the IterationType is Daily  # noqa: E501

        :return: The daily_contract of this IterationContract.  # noqa: E501
        :rtype: IterationDailyContract
        """
        return self._daily_contract

    @daily_contract.setter
    def daily_contract(self, daily_contract):
        """Sets the daily_contract of this IterationContract.

        Required when the IterationType is Daily  # noqa: E501

        :param daily_contract: The daily_contract of this IterationContract.  # noqa: E501
        :type: IterationDailyContract
        """

        self._daily_contract = daily_contract

    @property
    def weekly_contract(self):
        """Gets the weekly_contract of this IterationContract.  # noqa: E501

        Required when the IterationType is Weekly  # noqa: E501

        :return: The weekly_contract of this IterationContract.  # noqa: E501
        :rtype: IterationWeeklyContract
        """
        return self._weekly_contract

    @weekly_contract.setter
    def weekly_contract(self, weekly_contract):
        """Sets the weekly_contract of this IterationContract.

        Required when the IterationType is Weekly  # noqa: E501

        :param weekly_contract: The weekly_contract of this IterationContract.  # noqa: E501
        :type: IterationWeeklyContract
        """

        self._weekly_contract = weekly_contract

    @property
    def monthly_contract(self):
        """Gets the monthly_contract of this IterationContract.  # noqa: E501

        Required when the IterationType is Monthly  # noqa: E501

        :return: The monthly_contract of this IterationContract.  # noqa: E501
        :rtype: IterationMonthlyContract
        """
        return self._monthly_contract

    @monthly_contract.setter
    def monthly_contract(self, monthly_contract):
        """Sets the monthly_contract of this IterationContract.

        Required when the IterationType is Monthly  # noqa: E501

        :param monthly_contract: The monthly_contract of this IterationContract.  # noqa: E501
        :type: IterationMonthlyContract
        """

        self._monthly_contract = monthly_contract

    @property
    def custom_contract(self):
        """Gets the custom_contract of this IterationContract.  # noqa: E501

        Required when the IterationType is Custom  # noqa: E501

        :return: The custom_contract of this IterationContract.  # noqa: E501
        :rtype: IterationCustomContract
        """
        return self._custom_contract

    @custom_contract.setter
    def custom_contract(self, custom_contract):
        """Sets the custom_contract of this IterationContract.

        Required when the IterationType is Custom  # noqa: E501

        :param custom_contract: The custom_contract of this IterationContract.  # noqa: E501
        :type: IterationCustomContract
        """

        self._custom_contract = custom_contract

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(IterationContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IterationContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IterationContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class SearchUserContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "active": "bool",
        "email": "str",
        "role": "str",
        "first_name": "str",
        "last_name": "str",
        "created_after": "datetime",
        "created_before": "datetime",
    }

    attribute_map = {
        "active": "active",
        "email": "email",
        "role": "role",
        "first_name": "firstName",
        "last_name": "lastName",
        "created_after": "createdAfter",
        "created_before": "createdBefore",
    }

    def __init__(
        self,
        active=None,
        email=None,
        role=None,
        first_name=None,
        last_name=None,
        created_after=None,
        created_before=None,
        _configuration=None,
    ):  # noqa: E501
        """SearchUserContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active = None
        self._email = None
        self._role = None
        self._first_name = None
        self._last_name = None
        self._created_after = None
        self._created_before = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if email is not None:
            self.email = email
        if role is not None:
            self.role = role
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if created_after is not None:
            self.created_after = created_after
        if created_before is not None:
            self.created_before = created_before

    @property
    def active(self):
        """Gets the active of this SearchUserContract.  # noqa: E501


        :return: The active of this SearchUserContract.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this SearchUserContract.


        :param active: The active of this SearchUserContract.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def email(self):
        """Gets the email of this SearchUserContract.  # noqa: E501


        :return: The email of this SearchUserContract.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this SearchUserContract.


        :param email: The email of this SearchUserContract.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def role(self):
        """Gets the role of this SearchUserContract.  # noqa: E501


        :return: The role of this SearchUserContract.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this SearchUserContract.


        :param role: The role of this SearchUserContract.  # noqa: E501
        :type: str
        """
        allowed_values = ["NoAccess", "Viewer", "Member", "Artisan", "Curator", "Evaluated"]  # noqa: E501
        if self._configuration.client_side_validation and role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}".format(role, allowed_values)  # noqa: E501
            )

        self._role = role

    @property
    def first_name(self):
        """Gets the first_name of this SearchUserContract.  # noqa: E501


        :return: The first_name of this SearchUserContract.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this SearchUserContract.


        :param first_name: The first_name of this SearchUserContract.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this SearchUserContract.  # noqa: E501


        :return: The last_name of this SearchUserContract.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this SearchUserContract.


        :param last_name: The last_name of this SearchUserContract.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def created_after(self):
        """Gets the created_after of this SearchUserContract.  # noqa: E501


        :return: The created_after of this SearchUserContract.  # noqa: E501
        :rtype: datetime
        """
        return self._created_after

    @created_after.setter
    def created_after(self, created_after):
        """Sets the created_after of this SearchUserContract.


        :param created_after: The created_after of this SearchUserContract.  # noqa: E501
        :type: datetime
        """

        self._created_after = created_after

    @property
    def created_before(self):
        """Gets the created_before of this SearchUserContract.  # noqa: E501


        :return: The created_before of this SearchUserContract.  # noqa: E501
        :rtype: datetime
        """
        return self._created_before

    @created_before.setter
    def created_before(self, created_before):
        """Sets the created_before of this SearchUserContract.


        :param created_before: The created_before of this SearchUserContract.  # noqa: E501
        :type: datetime
        """

        self._created_before = created_before

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(SearchUserContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchUserContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchUserContract):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from src.server_client.api.collections_api import CollectionsApi
from src.server_client.api.credentials_api import CredentialsApi
from src.server_client.api.dcme_api import DCMEApi
from src.server_client.api.dcme_admin_api import DCMEAdminApi
from src.server_client.api.dcme_connect_api import DCMEConnectApi
from src.server_client.api.jobs_api import JobsApi
from src.server_client.api.schedules_api import SchedulesApi
from src.server_client.api.server_connections_api import ServerConnectionsApi
from src.server_client.api.subscriptions_api import SubscriptionsApi
from src.server_client.api.user_groups_api import UserGroupsApi
from src.server_client.api.users_api import UsersApi
from src.server_client.api.workflows_api import WorkflowsApi
